// You can import API functions like this from D3.js.
import { select } from 'd3';

// You can import local modules like this.
import { generateData } from './generatedata';


const csvUrl = [
  'https://gist.githubusercontent.com/kannamAmulyachowdary/7737cda809abd2c1d4c3e8522aa209f4/raw/0e1d24d8e83a1a5abf3a106765c12bd874526331/AK.csv', 
].join('');
console.clear();

const data = generateData();


const parseRow = (d) => {
  d.RoadLengthCm = +d.RoadLengthCm;
  d.RoadWidthCm = +d.RoadWidthCm;
  d.RideLengthCm = +d.RideLengthCm;
  d.RideWidthCm = +d.RideWidthCm;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.RideLengthCm;
const yValue = (d) => d.RideWidthCm;
const rxValue = (d) => d.RoadLengthCm;
const ryValue = (d) => d.RoadWidthCm;
const VaritiesValue = (d) => d.Varities;
const colorValue = d => d.Varities;
const colorLabel = 'Varities';

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.RideWidthCm);
  const y = yValue((d) => d.RoadLengthCm);
  const marker = (d) => {
        	switch(d){
            case 'word-wrap':
              return 'grey';
            case 'word-color':
              return 'white';
            default:
              return 'yellow';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.RideWidthCm),
          y: yValue((d) => d.RoadLengthCm),
          Varities: VaritiesValue(d),
          color: marker(VaritiesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
//Defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.RideWidthCm)
    .yValue((d) => d.RoadLengthCm)
    .margin({
      top: 35,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(5);
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);

//Defining the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

const columns = [
    'RideWidthCm',
    'RoadWidthCm',
    'RideLengthCm',
    'RoadLengthCm',
  ];

  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  /* Generates  'RideWidthCm',
    'RoadWidthCm',
    'RideLengthCm',
    'RoadLengthCm'*/
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","black")
          .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("word-wrap").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("word-color").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("word-country").style("font-size", "20px").attr("alignment-baseline","middle")
    
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("Road Length");
    
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "orange")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "blue")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "white")
   // plot RideWidthCm on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Road Width");
     // plot RoadWidthCm on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Road Width");
     // plot RideLengthCm on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Ride Length");
     // plot RoadLengthCm on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Road Width");
    i++;
  }, 2000);// every 2 seconds change the visualization
};
main();
